@@ -36,7 +36,7 @@ Diagnostics messages, typically rendered to STDERR.
 
 =head1 SYNOPSIS
 
-    use Test2 qw/context/;
+    use Test2::API qw/context/;
     use Test2::Event::Diag;
 
     my $ctx = context();
