@@ -36,7 +36,7 @@ Notes, typically rendered to STDOUT.
 
 =head1 SYNOPSIS
 
-    use Test2 qw/context/;
+    use Test2::API qw/context/;
     use Test2::Event::Note;
 
     my $ctx = context();
